﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Windows.Forms;
using System.Threading;
using System.Reflection;
using System.IO;
using RootPro.RootProCAD;
using RootPro.RootProCAD.Command;
using RootPro.RootProCAD.Geometry;
using RootPro.RootProCAD.UI;

//////////////////////////////////////////////////////////////////////////////////////
// 連続印刷のアドイン
// 複数の図面ファイルを指定して、連続して印刷を実行することができます。
//////////////////////////////////////////////////////////////////////////////////////

namespace RCAddInMultiPrintCS
{
    [System.AddIn.AddIn("AppAddIn", Version = "1.0", Publisher = "", Description = "")]
    public partial class AppAddIn
    {
        private void AppAddIn_Startup(object sender, EventArgs e)
        {
			AppDomain.CurrentDomain.AssemblyResolve += new ResolveEventHandler(ResolveAssembly);

			// コマンドをメニューに登録
			CommandManager.AddMacroCommand("RCAddInMultiPrintCS", Properties.Resources.CommandName, MacroCommand);
        }

        private void AppAddIn_Shutdown(object sender, EventArgs e)
        {
            // メニューからコマンドを削除
            CommandManager.RemoveMacroCommand(MacroCommand);
        }

        #region VSTA generated code
        private void InternalStartup()
        {
            this.Startup += new System.EventHandler(AppAddIn_Startup);
            this.Shutdown += new System.EventHandler(AppAddIn_Shutdown);
        }
        #endregion

        private void MacroCommand()
        {
            // フォームを表示する
            Form1 form = new Form1(this);
            form.ShowDialog();
        }

		private Assembly ResolveAssembly(object sender, ResolveEventArgs args)
		{
			AssemblyName assemblyName = new AssemblyName(args.Name);

			foreach (Assembly assembly in AppDomain.CurrentDomain.GetAssemblies())
			{
				if (AssemblyName.ReferenceMatchesDefinition(assemblyName, assembly.GetName()))
					return assembly;
			}

			if (assemblyName.Name.EndsWith(".resources"))
			{
				if (assemblyName.CultureName.Equals(Thread.CurrentThread.CurrentUICulture.Name, StringComparison.OrdinalIgnoreCase))
				{
					string dllPath = Path.GetDirectoryName(this.AddInFullPath);
					dllPath = Path.Combine(dllPath, assemblyName.CultureName);
					dllPath = Path.Combine(dllPath, assemblyName.Name + ".dll");

					if (File.Exists(dllPath))
					{
						try
						{
							return Assembly.LoadFrom(dllPath);
						}
						catch
						{
						}
					}
				}
			}

			return null;
		}
	}
}
